@@ -319,7 +319,7 @@ class ExecuteSolverFunction(ExecuteFunction):
                         data_set.add(NetworkFlow(orig_name=i,dest_name=j,commod_name=h,flow=solution[h,i,j]))
 
         status = m.status                        
-        if status == GRB.status.INF_OR_UNBD or status == GRB.status.INFEASIBLE or status == GRB.status.UNBOUNDED:
+        if status == gurobipy.GRB.status.INF_OR_UNBD or status == gurobipy.GRB.status.INFEASIBLE or status == gurobipy.GRB.status.UNBOUNDED:
             data_set.send_progress_message('The model cannot be solved because it is infeasible or unbounded')
         else:
             data_set.send_progress_message('Total cost = %s' % (str(m.objVal)))
