@@ -18,7 +18,7 @@ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
-from gurobipy import GRB, Model, quicksum, tuplelist
+import gurobipy # Note eclipse has problems importing quicksum so we dont import selectively
 from sqlalchemy.types import Integer, Text, Float
 from sqlalchemy.schema import Column, ForeignKeyConstraint, UniqueConstraint
 
@@ -36,7 +36,9 @@ class ShiftRequirements(DataSetMixin):
         self.day = day
         self.staff = staff
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'day'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'day'),)
 
 
 class Staff(DataSetMixin):
@@ -47,7 +49,9 @@ class Staff(DataSetMixin):
         self.name = name
         self.rate = rate
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
 
 
 class Availability(DataSetMixin):
@@ -58,10 +62,12 @@ class Availability(DataSetMixin):
         self.staff_name = staff_name
         self.day = day
 
-    __table_args__ = (
-        ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
 
 class ShiftsWorkedForLeastCost(DataSetMixin):
@@ -72,10 +78,12 @@ class ShiftsWorkedForLeastCost(DataSetMixin):
         self.staff_name = staff_name
         self.day = day
 
-    __table_args__ = (
-        ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
 
 class ShiftsWorkedForEvenWorkings(DataSetMixin):
@@ -86,10 +94,12 @@ class ShiftsWorkedForEvenWorkings(DataSetMixin):
         self.staff_name = staff_name
         self.day = day
 
-    __table_args__ = (
-        ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            ForeignKeyConstraint(['staff_name', 'data_set_id'], ['staff.name', 'staff.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['day', 'data_set_id'], ['shiftrequirements.day', 'shiftrequirements.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
 
 class ExecuteGurobiSolver(ExecuteFunction):
@@ -312,16 +322,16 @@ def formulate_and_solve_staff_rostering_problem(data_set):
     availability = []
     for a in data_set.query(Availability).all():
         availability.append((a.staff_name, a.day))
-    availability = tuplelist(availability)
+    availability = gurobipy.tuplelist(availability)
 
     # Model
-    m = Model("assignment")
+    m = gurobipy.Model("assignment")
 
     # Assignment variables: x[w,s] == 1 if worker w is assigned to shift s.
     # This is no longer a pure assignment model, so we must use binary variables.
     x = {}
     for w, s in availability:
-        x[w, s] = m.addVar(vtype=GRB.BINARY, obj=pay[w], name=w + "." + s)
+        x[w, s] = m.addVar(vtype=gurobipy.GRB.BINARY, obj=pay[w], name=w + "." + s)
 
     # Slack variables for each shift constraint so that the shifts can
     # be satisfied
@@ -343,14 +353,14 @@ def formulate_and_solve_staff_rostering_problem(data_set):
     # Constraint: assign exactly shiftRequirements[s] workers to each shift s,
     # plus the slack
     for s in shifts:
-        m.addConstr(slacks[s] + quicksum(x[w, s] for w, s in availability.select('*', s)) == shiftRequirements[s], s)
+        m.addConstr(slacks[s] + gurobipy.quicksum(x[w, s] for w, s in availability.select('*', s)) == shiftRequirements[s], s)
 
     # Constraint: set totSlack equal to the total slack
-    m.addConstr(totSlack == quicksum(slacks[s] for s in shifts), "totSlack")
+    m.addConstr(totSlack == gurobipy.quicksum(slacks[s] for s in shifts), "totSlack")
 
     # Constraint: compute the total number of shifts for each worker
     for w in workers:
-        m.addConstr(totShifts[w] == quicksum(x[w, s] for w, s in availability.select(w, '*')), "totShifts" + w)
+        m.addConstr(totShifts[w] == gurobipy.quicksum(x[w, s] for w, s in availability.select(w, '*')), "totShifts" + w)
 
     # Objective: minimize the total slack
     # Note that this replaces the previous 'pay' objective coefficients
@@ -361,10 +371,10 @@ def formulate_and_solve_staff_rostering_problem(data_set):
         data_set.send_progress_message(msg)
         m.optimize()
         status = m.status
-        if status == GRB.status.INF_OR_UNBD or status == GRB.status.INFEASIBLE or status == GRB.status.UNBOUNDED:
+        if status == gurobipy.GRB.status.INF_OR_UNBD or status == gurobipy.GRB.status.INFEASIBLE or status == gurobipy.GRB.status.UNBOUNDED:
             data_set.send_progress_message('The model cannot be solved because it is infeasible or unbounded')
 
-        if status != GRB.status.OPTIMAL:
+        if status != gurobipy.GRB.status.OPTIMAL:
             data_set.send_progress_message('Optimization was stopped with status %s' % (str(status)))
 
         # Print total slack and the number of shifts worked for each worker
@@ -393,13 +403,13 @@ def formulate_and_solve_staff_rostering_problem(data_set):
     # note that these variables can take negative values.
     diffShifts = {}
     for w in workers:
-        diffShifts[w] = m.addVar(lb=-GRB.INFINITY, ub=GRB.INFINITY, name=w + "Diff")
+        diffShifts[w] = m.addVar(lb=-gurobipy.GRB.INFINITY, ub=gurobipy.GRB.INFINITY, name=w + "Diff")
 
     # Update model to integrate new variables
     m.update()
 
     # Constraint: compute the average number of shifts worked
-    m.addConstr(len(workers) * avgShifts == quicksum(totShifts[w] for w in workers), "avgShifts")
+    m.addConstr(len(workers) * avgShifts == gurobipy.quicksum(totShifts[w] for w in workers), "avgShifts")
 
     # Constraint: compute the difference from the average number of shifts
     for w in workers:
@@ -407,7 +417,7 @@ def formulate_and_solve_staff_rostering_problem(data_set):
 
     # Objective: minimize the sum of the square of the difference from the
     # average number of shifts worked
-    m.setObjective(quicksum(diffShifts[w] * diffShifts[w] for w in workers))
+    m.setObjective(gurobipy.quicksum(diffShifts[w] * diffShifts[w] for w in workers))
 
     # Optimize
     solveAndPrint('<br>Minimising the square of the differences from the average number of shifts worked', ShiftsWorkedForEvenWorkings, data_set)
