@@ -49,7 +49,9 @@ class MaxWCutNode(DataSetMixin):
     longitude = Column(Float, nullable=False)
     allocated_group_index = Column(Boolean)  # Only 2 possible groups, thus boolean.
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls): 
+        return (UniqueConstraint('data_set_id', 'name'),)
 
     @classmethod
     def get_ordered_list_of_all_nodes(cls, data_set):
@@ -65,11 +67,13 @@ class MaxWCutArc(DataSetMixin):
     orig_node = relationship(MaxWCutNode, primaryjoin="and_(MaxWCutArc.data_set_id==MaxWCutNode.data_set_id, MaxWCutArc.orig_name==MaxWCutNode.name)")
     dest_node = relationship(MaxWCutNode, primaryjoin="and_(MaxWCutArc.data_set_id==MaxWCutNode.data_set_id, MaxWCutArc.dest_name==MaxWCutNode.name)")
 
-    __table_args__ = (
-        UniqueConstraint('data_set_id', 'orig_name', 'dest_name'),
-        ForeignKeyConstraint(['orig_name', 'data_set_id'], ['maxwcutnode.name', 'maxwcutnode.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['dest_name', 'data_set_id'], ['maxwcutnode.name', 'maxwcutnode.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            UniqueConstraint('data_set_id', 'orig_name', 'dest_name'),
+            ForeignKeyConstraint(['orig_name', 'data_set_id'], ['maxwcutnode.name', 'maxwcutnode.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['dest_name', 'data_set_id'], ['maxwcutnode.name', 'maxwcutnode.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
     @property
     def in_cut(self):
