@@ -12,7 +12,9 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
 from sqlalchemy import Column, Text, Float
-from tropofy import DataSetMixin, AppWithDataSets, Step, StepGroup, SimpleGrid
+from tropofy.database.tropofy_orm import DataSetMixin
+from tropofy.app import AppWithDataSets, Step, StepGroup
+from tropofy.widgets import SimpleGrid
 
 
 class MyLocation(DataSetMixin):
